# Trading Hours

initial code by **Neosb** Szymon Błaszczyński @museyoucoulduse [github.com/buahaha](https://github.com/buahaha)

## Usage

1. `tradinghours`
2. `symbol MSFT`

or

1. `tradinghours`
    - `open`
    - `closed`
    - `all`

___

## Reference data

[Exchanges in Yahoo Finance](https://help.yahoo.com/kb/SLN2310.html)
